@@ -3,7 +3,7 @@
 # parser benchmark
 #
 
-require 'tmail/tmail'
+require 'tmail'
 
 
 if ARGV.size == 0 then
